# pyeuler3d

Python package interfacing with the ***awesome*** [Euler3D CFD software](https://github.com/AER8875-Projet-integrateur-IV/Euler3D)

## Use

## Contribute

1. Install pipenv   (first time only)

```
    $   sudo apt install pipenv
```

2. Create a virtual environment (first time only)

```
    $   pipenv  shell
```

3. Sync your environment    (every time you work on the package)

```
    $   pipenv update
```
